#! /usr/bin/env python
"""XSetBg database

"""

__author__ = "Oleg Broytman <phd@phdru.name>"
__copyright__ = "Copyright (C) 2014, 2015 PhiloSoft Design"
__license__ = "GNU GPL"

__all__ = ['xsetbg_db_path', 'xsetbg_db']

import os
from sqlobject import SQLObject, connectionForURI, sqlhub, \
    StringCol, UnicodeCol, IntCol, BoolCol, dberrors
from xsetbg_conf import xsetbg_conf


class SqliteSequence(SQLObject):
    class sqlmeta:
        idName = 'rowid'
    name = StringCol(unique=True)
    seq = IntCol()


class XSetBg(SQLObject):
    full_name = UnicodeCol(alternateID=True)
    last_shown = IntCol(default=None)  # timestamp
    flag = BoolCol(default=None)


db_dirs = []
try:
    xsetbg_db_path = xsetbg_conf.get('xsetbg', 'database')
except:
    xsetbg_db_path = None

if not xsetbg_db_path:
    if 'XDG_CACHE_HOME' in os.environ:
        db_dirs.append(os.environ['XDG_CACHE_HOME'])
    home_cache = os.path.expanduser('~/.cache')
    if home_cache not in db_dirs:
        db_dirs.append(home_cache)
    db_dirs.append(os.path.dirname(os.path.abspath(__file__)))

    for d in db_dirs:
        xsetbg_db_path = os.path.join(d, 'xsetbg.sqlite')
        if os.path.exists(xsetbg_db_path):
            break

if xsetbg_db_path:
    sqlhub.processConnection = \
        connectionForURI('sqlite:///%s' % xsetbg_db_path)
    try:
        XSetBg.select()[0]
    except IndexError:
        xsetbg_db = XSetBg  # Table exists but is empty
    except dberrors.Error:
        xsetbg_db = None
    else:
        xsetbg_db = XSetBg
else:
    xsetbg_db = None

if __name__ == '__main__':
    print "DB dirs:", db_dirs
    print "DB file:", xsetbg_db_path
